@@ -34,7 +34,7 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include "file-utils.h"
 #include "fr-stock.h"
-#include "window.h"
+#include "fr-window.h"
 #include "gtk-utils.h"
 
 
@@ -42,7 +42,7 @@
 
 
 typedef struct {
-	FRWindow    *window;
+	FrWindow    *window;
 	GtkTooltips *tooltips;
 	GtkWidget   *dialog;
 	GtkWidget   *include_subfold_checkbutton;
@@ -73,7 +73,7 @@ static gboolean
 utf8_only_spaces (const char *text)
 {
 	const char *scan;
-	
+
 	if (text == NULL)
 		return TRUE;
 
@@ -93,7 +93,7 @@ file_sel_response_cb (GtkWidget    *widget,
 		      DialogData   *data)
 {
 	GtkFileChooser *file_sel = GTK_FILE_CHOOSER (widget);
-	FRWindow       *window = data->window;
+	FrWindow       *window = data->window;
 	char           *current_folder;
 	gboolean        update, recursive, follow_links;
 	GSList         *selections, *iter;
@@ -109,37 +109,33 @@ file_sel_response_cb (GtkWidget    *widget,
 		return TRUE;
 	}
 
-	current_folder = gtk_file_chooser_get_current_folder (file_sel);
+	current_folder = gtk_file_chooser_get_current_folder_uri (file_sel);
 
 	/* check folder permissions. */
 
-	if (path_is_dir (current_folder) 
-	    && access (current_folder, R_OK | X_OK) != 0) {
+	if (path_is_dir (current_folder)
+	    && ! check_permissions (current_folder, R_OK | X_OK)) {
 		GtkWidget *d;
 		char      *utf8_path;
-		char      *message;
 
 		utf8_path = g_filename_display_name (current_folder);
-		message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
-		g_free (utf8_path);
 
-		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-					     GTK_DIALOG_MODAL,
-					     GTK_STOCK_DIALOG_ERROR,
-					     _("Could not add the files to the archive"),
-					     message,
-					     GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
-					     NULL);
+		d = _gtk_error_dialog_new (GTK_WINDOW (window),
+					   GTK_DIALOG_MODAL,
+					   NULL,
+					   _("Could not add the files to the archive"),
+					   _("You don't have the right permissions to read files from folder \"%s\""), 
+					   utf8_path);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
-		g_free (message);
 
+		g_free (utf8_path);
 		g_free (current_folder);
 
 		return FALSE;
 	}
 
-	window_set_add_default_dir (window, current_folder);
+	fr_window_set_add_default_dir (window, current_folder);
 
 	update = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->add_if_newer_checkbutton));
 	recursive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton));
@@ -147,7 +143,7 @@ file_sel_response_cb (GtkWidget    *widget,
 
 	/**/
 
-	selections = gtk_file_chooser_get_filenames (file_sel);
+	selections = gtk_file_chooser_get_uris (file_sel);
 	for (iter = selections; iter != NULL; iter = iter->next) {
 		char *path = iter->data;
 		item_list = g_list_prepend (item_list, path);
@@ -157,6 +153,7 @@ file_sel_response_cb (GtkWidget    *widget,
 		const char *folder = (char*) item_list->data;
 		const char *include_files = gtk_entry_get_text (GTK_ENTRY (data->include_files_entry));
 		const char *exclude_files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
+		char       *dest_uri;
 		char       *dest_dir;
 
 		if (utf8_only_spaces (include_files))
@@ -164,23 +161,23 @@ file_sel_response_cb (GtkWidget    *widget,
 		if (utf8_only_spaces (exclude_files))
 			exclude_files = NULL;
 
-		dest_dir = g_build_path (G_DIR_SEPARATOR_S,
-					 window_get_current_location (window),
+		dest_uri = g_build_path (G_DIR_SEPARATOR_S,
+					 fr_window_get_current_location (window),
 					 file_name_from_path (folder),
 					 NULL);
-		
-		window_archive_add_with_wildcard (window,
-						  include_files,
-						  exclude_files,
-						  folder,
-						  dest_dir,
-						  update,
-						  recursive,
-						  follow_links,
-						  window->password,
-						  window->compression);
+		dest_dir = get_local_path_from_uri (dest_uri);
+
+		fr_window_archive_add_with_wildcard (window,
+						     include_files,
+						     exclude_files,
+						     folder,
+						     dest_dir,
+						     update,
+						     recursive,
+						     follow_links);
 
 		g_free (dest_dir);
+		g_free (dest_uri);
 	}
 
 	g_list_free (item_list);
@@ -195,96 +192,46 @@ file_sel_response_cb (GtkWidget    *widget,
 
 
 static void
-update_sensitivity (DialogData *data)
-{
-	GSList   *selections;
-	gboolean  can_add_wildcard, wildcard_specified = FALSE;
-
-
-	selections = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (data->dialog));
-	can_add_wildcard = (selections != NULL);
-
-	if (can_add_wildcard) {
-		const char *files;
-		gboolean    include_wildcard;
-		gboolean    exclude_wildcard;
-
-		files = gtk_entry_get_text (GTK_ENTRY (data->include_files_entry));
-		include_wildcard = ((g_utf8_strchr (files, -1, '*') != NULL) 
-				    || (g_utf8_strchr (files, -1, '?') != NULL));
-
-		files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
-		exclude_wildcard = ((g_utf8_strchr (files, -1, '*') != NULL) 
-				    || (g_utf8_strchr (files, -1, '?') != NULL));
-		wildcard_specified = include_wildcard || exclude_wildcard;
-	}
-
-	gtk_widget_set_sensitive (data->include_files_entry, can_add_wildcard);
-	gtk_widget_set_sensitive (data->exclude_files_entry, can_add_wildcard);
-	gtk_widget_set_sensitive (data->include_files_label, can_add_wildcard);
-	gtk_widget_set_sensitive (data->exclude_files_label, can_add_wildcard);
-	gtk_widget_set_sensitive (data->include_subfold_checkbutton, can_add_wildcard);
-	gtk_widget_set_sensitive (data->exclude_symlinks, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton)) && can_add_wildcard);
-
-	g_slist_foreach (selections, (GFunc) g_free, FALSE);
-	g_slist_free (selections);
-}
-
-
-static void
-selection_changed_cb (GtkWidget  *file_sel, 
+selection_changed_cb (GtkWidget  *file_sel,
 		      DialogData *data)
 {
-	FRWindow   *window = data->window;
-	char       *current_folder;
+	FrWindow *window = data->window;
+	char     *current_folder;
 
-        current_folder = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_sel));
+	current_folder = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (file_sel));
 
-        /* check folder permissions. */
-                                                                                                
-        if (path_is_dir (current_folder)
-            && access (current_folder, R_OK | X_OK) != 0) {
-                GtkWidget *d;
-                char      *utf8_path;
-                char      *message;
-		
-                utf8_path = g_filename_display_name (current_folder);
-                message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
-                g_free (utf8_path);
-		
-                d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-                                             GTK_DIALOG_MODAL,
-                                             GTK_STOCK_DIALOG_ERROR,
-                                             _("Could not add the files to the archive"),
-                                             message,
-                                             GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
-                                             NULL);
-                gtk_dialog_run (GTK_DIALOG (d));
-                gtk_widget_destroy (GTK_WIDGET (d));
-                g_free (message);
-		
-                g_free (current_folder);
-        }
+	/* check folder permissions. */
 
-	update_sensitivity (data);
-}
+	if (path_is_dir (current_folder) && ! check_permissions (current_folder, R_OK | X_OK)) {
+		GtkWidget *d;
+		char      *utf8_path;
 
+		utf8_path = g_filename_display_name (current_folder);
 
-static void
-wildcard_entry_changed_cb (GtkWidget  *file_sel, 
-			   DialogData *data)
-{
-	update_sensitivity (data);
+		d = _gtk_error_dialog_new (GTK_WINDOW (window),
+					   GTK_DIALOG_MODAL,
+					   NULL,
+					   _("Could not add the files to the archive"),
+					   _("You don't have the right permissions to read files from folder \"%s\""), 
+					   utf8_path);
+		gtk_dialog_run (GTK_DIALOG (d));
+		gtk_widget_destroy (GTK_WIDGET (d));
+
+		g_free (utf8_path);
+		g_free (current_folder);
+	}
 }
 
 
 static int
-include_subfold_toggled_cb (GtkWidget *widget, 
+include_subfold_toggled_cb (GtkWidget *widget,
 			    gpointer   callback_data)
 {
 	DialogData *data = callback_data;
+
 	gtk_widget_set_sensitive (data->exclude_symlinks,
 				  GTK_TOGGLE_BUTTON (widget)->active);
+
 	return FALSE;
 }
 
@@ -295,15 +242,14 @@ static void save_options_cb (GtkWidget *w, DialogData *data);
 
 /* create the "add" dialog. */
 void
-add_folder_cb (GtkWidget *widget, 
+add_folder_cb (GtkWidget *widget,
 	       void      *callback_data)
 {
 	GtkWidget   *file_sel;
 	DialogData  *data;
-	gchar       *dir;
 	GtkWidget   *main_box;
 	GtkWidget   *vbox;
-	GtkWidget   *table;	
+	GtkWidget   *table;
 
 	data = g_new0 (DialogData, 1);
 
@@ -313,19 +259,19 @@ add_folder_cb (GtkWidget *widget,
 	g_object_ref (G_OBJECT (data->tooltips));
 	gtk_object_sink (GTK_OBJECT (data->tooltips));
 
-	data->dialog = file_sel = 
+	data->dialog = file_sel =
 		gtk_file_chooser_dialog_new (_("Add a Folder"),
-					     GTK_WINDOW (data->window->app),
+					     GTK_WINDOW (data->window),
 					     GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     FR_STOCK_ADD_FOLDER, GTK_RESPONSE_OK,
 					     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 					     NULL);
-	
+
 	gtk_window_set_default_size (GTK_WINDOW (data->dialog), 530, 510);
-					     
+
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (file_sel), FALSE);
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), TRUE);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
 
 	data->add_if_newer_checkbutton = gtk_check_button_new_with_mnemonic (_("_Add only if newer"));
@@ -353,7 +299,7 @@ add_folder_cb (GtkWidget *widget,
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
 	gtk_box_pack_start (GTK_BOX (main_box), vbox, TRUE, TRUE, 0);
 
-	gtk_box_pack_start (GTK_BOX (vbox), data->add_if_newer_checkbutton, 
+	gtk_box_pack_start (GTK_BOX (vbox), data->add_if_newer_checkbutton,
 			    TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), data->include_subfold_checkbutton,
 			    TRUE, TRUE, 0);
@@ -366,7 +312,7 @@ add_folder_cb (GtkWidget *widget,
 	gtk_box_pack_start (GTK_BOX (vbox), table,
 			    TRUE, TRUE, 0);
 
-	gtk_table_attach (GTK_TABLE (table), 
+	gtk_table_attach (GTK_TABLE (table),
 			  data->include_files_label,
 			  0, 1,
 			  0, 1,
@@ -378,7 +324,7 @@ add_folder_cb (GtkWidget *widget,
 			  0, 1,
 			  GTK_FILL|GTK_EXPAND, 0,
 			  0, 0);
-	gtk_table_attach (GTK_TABLE (table), 
+	gtk_table_attach (GTK_TABLE (table),
 			  data->exclude_files_label,
 			  0, 1,
 			  1, 2,
@@ -392,30 +338,25 @@ add_folder_cb (GtkWidget *widget,
 			  0, 0);
 
 	/**/
-	
+
 	vbox = gtk_vbox_new (FALSE, 5);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
 	gtk_box_pack_start (GTK_BOX (main_box), vbox, FALSE, FALSE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (vbox), data->load_button,
 			    FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), data->save_button,
 			    FALSE, FALSE, 0);
 
 	gtk_widget_show_all (main_box);
-	
+
 	/* set data */
 
-	dir = g_strconcat (data->window->add_default_dir, "/", "*", NULL);
-	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_sel), dir);
-	g_free (dir);
-
+	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (file_sel), fr_window_get_add_default_dir (data->window));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton), TRUE);
 
-	update_sensitivity (data);
-
 	/* signals */
-	
+
 	g_signal_connect (G_OBJECT (file_sel),
 			  "destroy", 
 			  G_CALLBACK (open_file_destroy_cb),
@@ -426,20 +367,11 @@ add_folder_cb (GtkWidget *widget,
 			  G_CALLBACK (file_sel_response_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (file_sel), 
+	g_signal_connect (G_OBJECT (file_sel),
 			  "selection-changed",
 			  G_CALLBACK (selection_changed_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (data->include_files_entry), 
-			  "changed",
-			  G_CALLBACK (wildcard_entry_changed_cb),
-			  data);
-	g_signal_connect (G_OBJECT (data->exclude_files_entry), 
-			  "changed",
-			  G_CALLBACK (wildcard_entry_changed_cb),
-			  data);
-	
 	g_signal_connect (G_OBJECT (data->include_subfold_checkbutton),
 			  "toggled", 
 			  G_CALLBACK (include_subfold_toggled_cb),
@@ -449,7 +381,7 @@ add_folder_cb (GtkWidget *widget,
 			  "clicked",
 			  G_CALLBACK (load_options_cb), 
 			  data);
-	
+
 	g_signal_connect (G_OBJECT (data->save_button),
 			  "clicked",
 			  G_CALLBACK (save_options_cb), 
@@ -484,11 +416,11 @@ config_get_bool (const char *config_file,
 {
 	char     *path;
 	gboolean  value;
-	
+
 	path = g_strconcat ("=", config_file, "=/Options/", option, NULL);
 	value = gnome_config_get_bool (path);
 	g_free (path);
-	
+
 	return value;
 }
 
@@ -499,11 +431,11 @@ config_get_string (const char *config_file,
 {
 	char *path;
 	char *value;
-	
+
 	path = g_strconcat ("=", config_file, "=/Options/", option, NULL);
 	value = gnome_config_get_string (path);
 	g_free (path);
-	
+
 	return value;
 }
 
@@ -526,7 +458,7 @@ aod_apply_cb (GtkWidget *widget,
 	gboolean               no_symlinks;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aod_data->aod_treeview));
-	if (! gtk_tree_selection_get_selected (selection, NULL, &iter)) 
+	if (! gtk_tree_selection_get_selected (selection, NULL, &iter))
 		return;
 
 	gtk_tree_model_get (aod_data->aod_model, &iter,
@@ -537,7 +469,7 @@ aod_apply_cb (GtkWidget *widget,
 	data->last_options = g_strdup (file_name_from_path (file_path));
 
 	/* Load options. */
-	
+
 	base_dir = config_get_string (file_path, "base_dir");
 	filename = config_get_string (file_path, "filename");
 	include_files = config_get_string (file_path, "include_files");
@@ -550,13 +482,16 @@ aod_apply_cb (GtkWidget *widget,
 
 	/* Sync widgets with options. */
 
-	if (base_dir != NULL) { 
-		if ((filename != NULL) && (strcmp (filename, base_dir) != 0)) 
+	if (base_dir != NULL) {
+		if ((filename != NULL) && (strcmp (filename, base_dir) != 0))
 			gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (data->dialog), filename);
-		else
-			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (data->dialog), base_dir);
+		else {
+			char *uri = get_uri_from_path (base_dir);
+			gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->dialog), uri);
+			g_free (uri);
+		}
 	}
-		
+
 	if (include_files != NULL)
 		gtk_entry_set_text (GTK_ENTRY (data->include_files_entry), include_files);
 	if (exclude_files != NULL)
@@ -564,7 +499,7 @@ aod_apply_cb (GtkWidget *widget,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->add_if_newer_checkbutton), update);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton), recursive);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_symlinks), no_symlinks);
-	
+
 	g_free (base_dir);
 	g_free (filename);
 	g_free (include_files);
@@ -578,9 +513,9 @@ aod_apply_cb (GtkWidget *widget,
 
 static void
 aod_activated_cb (GtkTreeView       *tree_view,
-                  GtkTreePath       *path,
-                  GtkTreeViewColumn *column,
-                  gpointer           callback_data)
+		  GtkTreePath       *path,
+		  GtkTreeViewColumn *column,
+		  gpointer           callback_data)
 {
 	aod_apply_cb (NULL, callback_data);
 }
@@ -593,13 +528,13 @@ aod_update_option_list (LoadOptionsDialogData *aod_data)
 	char           *options_dir;
 	GnomeVFSResult  result;
 	GList          *list = NULL;
-	
+
 	gtk_list_store_clear (list_store);
 
 	options_dir = get_home_relative_dir (RC_OPTIONS_DIR);
 	ensure_dir_exists (options_dir, 0700);
-	
-	result = gnome_vfs_directory_list_load (&list, 
+
+	result = gnome_vfs_directory_list_load (&list,
 						options_dir,
 						GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
@@ -614,7 +549,7 @@ aod_update_option_list (LoadOptionsDialogData *aod_data)
 			if ((strcmp (file_info->name, ".") == 0)
 			    || (strcmp (file_info->name, "..") == 0))
 				continue;
-			
+
 			full_path = g_build_filename (options_dir,
 						      file_info->name,
 						      NULL);
@@ -627,7 +562,7 @@ aod_update_option_list (LoadOptionsDialogData *aod_data)
 			g_free (full_path);
 		}
 	}
-	
+
 	gnome_vfs_file_info_list_free (list);
 	g_free (options_dir);
 }
@@ -655,7 +590,7 @@ aod_remove_cb (GtkWidget             *widget,
 }
 
 
-static void 
+static void
 load_options_cb (GtkWidget  *w,
 		 DialogData *data)
 {
@@ -670,11 +605,11 @@ load_options_cb (GtkWidget  *w,
 
 	aod_data->data = data;
 	aod_data->gui = glade_xml_new (GLADEDIR "/" GLADE_FILE , NULL, NULL);
-        if (! aod_data->gui) {
-                g_warning ("Could not find " GLADE_FILE "\n");
+	if (! aod_data->gui) {
+		g_warning ("Could not find " GLADE_FILE "\n");
 		g_free (aod_data);
-                return;
-        }
+		return;
+	}
 
 	/* Get the widgets. */
 
@@ -687,34 +622,34 @@ load_options_cb (GtkWidget  *w,
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (aod_data->dialog), 
+	g_signal_connect (G_OBJECT (aod_data->dialog),
 			  "destroy",
 			  G_CALLBACK (aod_destroy_cb),
 			  aod_data);
 	g_signal_connect (G_OBJECT (aod_data->aod_treeview),
-                          "row_activated",
-                          G_CALLBACK (aod_activated_cb),
-                          aod_data);
-	g_signal_connect_swapped (G_OBJECT (cancel_button), 
+			  "row_activated",
+			  G_CALLBACK (aod_activated_cb),
+			  aod_data);
+	g_signal_connect_swapped (G_OBJECT (cancel_button),
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (aod_data->dialog));
-	g_signal_connect (G_OBJECT (ok_button), 
+	g_signal_connect (G_OBJECT (ok_button),
 			  "clicked",
 			  G_CALLBACK (aod_apply_cb),
 			  aod_data);
-	g_signal_connect (G_OBJECT (remove_button), 
+	g_signal_connect (G_OBJECT (remove_button),
 			  "clicked",
 			  G_CALLBACK (aod_remove_cb),
 			  aod_data);
 
 	/* Set data. */
 
-	aod_data->aod_model = GTK_TREE_MODEL (gtk_list_store_new (2, 
+	aod_data->aod_model = GTK_TREE_MODEL (gtk_list_store_new (2,
 								  G_TYPE_STRING,
 								  G_TYPE_STRING));
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (aod_data->aod_model),
-                                              0,
+					      0,
 					      GTK_SORT_ASCENDING);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (aod_data->aod_treeview),
 				 aod_data->aod_model);
@@ -730,12 +665,12 @@ load_options_cb (GtkWidget  *w,
 	gtk_tree_view_column_set_sort_column_id (column, 0);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (aod_data->aod_treeview),
 				     column);
-	
+
 	aod_update_option_list (aod_data);
 
 	/* Run */
 
-	gtk_window_set_transient_for (GTK_WINDOW (aod_data->dialog), 
+	gtk_window_set_transient_for (GTK_WINDOW (aod_data->dialog),
 				      GTK_WINDOW (data->dialog));
 	gtk_window_set_modal (GTK_WINDOW (aod_data->dialog), TRUE);
 	gtk_widget_show (aod_data->dialog);
@@ -748,7 +683,7 @@ config_set_bool (const char *config_file,
 		 gboolean    value)
 {
        char *path;
-       
+
        path = g_strconcat ("=", config_file, "=/Options/", option, NULL);
        gnome_config_set_bool (path, value);
 
@@ -762,7 +697,7 @@ config_set_string (const char *config_file,
 		   const char *value)
 {
 	char *path;
-	
+
 	path = g_strconcat ("=", config_file, "=/Options/", option, NULL);
 	gnome_config_set_string (path, value);
 
@@ -770,7 +705,7 @@ config_set_string (const char *config_file,
 }
 
 
-static void 
+static void
 save_options_cb (GtkWidget  *w,
 		 DialogData *data)
 {
@@ -798,14 +733,14 @@ save_options_cb (GtkWidget  *w,
 			GTK_STOCK_CANCEL,
 			GTK_STOCK_SAVE);
 
-	if (opt_filename == NULL) 
+	if (opt_filename == NULL)
 		return;
 
 	opt_file_path = g_build_filename (options_dir, opt_filename, NULL);
 	g_free (opt_filename);
 
 	/* Get options. */
-	
+
 	base_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (data->dialog));
 	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data->dialog));
 	update = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->add_if_newer_checkbutton));
@@ -819,9 +754,9 @@ save_options_cb (GtkWidget  *w,
 	exclude_files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
 	if (utf8_only_spaces (exclude_files))
 		exclude_files = NULL;
-	
+
 	/* Save options. */
-	
+
 	config_set_string (opt_file_path, "base_dir", base_dir);
 	config_set_string (opt_file_path, "filename", filename);
 	config_set_string (opt_file_path, "include_files", include_files);
@@ -835,7 +770,7 @@ save_options_cb (GtkWidget  *w,
 	data->last_options = g_strdup (file_name_from_path (opt_file_path));
 
 	/**/
-	
+
 	g_free (base_dir);
 	g_free (filename);
 	g_free (opt_file_path);
