@@ -31,6 +31,8 @@
 #include "fr-command.h"
 #include "fr-marshal.h"
 
+#define INITIAL_SIZE 256
+
 enum {
 	START,
 	DONE,
@@ -229,9 +231,10 @@ fr_command_class_init (FrCommandClass *class)
 static void
 fr_command_init (FrCommand *comm)
 {
+	comm->files = g_ptr_array_sized_new (INITIAL_SIZE);
+	
 	comm->filename = NULL;
 	comm->e_filename = NULL;
-	comm->file_list = NULL;
 	comm->fake_load = FALSE;
 
 	comm->propCanModify = TRUE;
@@ -252,6 +255,7 @@ fr_command_start (FrProcess *process,
 		  gpointer   data)
 {
 	FrCommand *comm = FR_COMMAND (data);
+	
 	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[START], 
 		       0,
@@ -317,12 +321,8 @@ fr_command_finalize (GObject *object)
 	if (comm->e_filename != NULL)
 		g_free (comm->e_filename);
 
-	if (comm->file_list != NULL) {
-		g_list_foreach (comm->file_list,
-				(GFunc) file_data_free,
-				NULL);
-		g_list_free (comm->file_list);
-	}
+	if (comm->files != NULL) 
+		g_ptr_array_free_full (comm->files, (GFunc) file_data_free, NULL);
 
 	g_signal_handlers_disconnect_matched (G_OBJECT (comm->process),
 					      G_SIGNAL_MATCH_DATA, 
@@ -376,16 +376,15 @@ fr_command_list (FrCommand  *comm,
 
 	fr_command_progress (comm, -1.0);
 
-	if (comm->file_list != NULL) {
-		g_list_foreach (comm->file_list, (GFunc) file_data_free, NULL);
-		g_list_free (comm->file_list);
-		comm->file_list = NULL;
+	if (comm->files != NULL) {
+		g_ptr_array_free_full (comm->files, (GFunc) file_data_free, NULL);
+		comm->files = g_ptr_array_sized_new (INITIAL_SIZE);
 	}
 
 	comm->action = FR_ACTION_LISTING_CONTENT;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
-
+	
 	if (!comm->fake_load)
 		FR_COMMAND_GET_CLASS (G_OBJECT (comm))->list (comm, password);
 }
@@ -404,6 +403,7 @@ fr_command_add (FrCommand     *comm,
 	comm->action = FR_ACTION_ADDING_FILES;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
+	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->add (comm,
 						     file_list,
 						     base_dir,
@@ -422,6 +422,7 @@ fr_command_delete (FrCommand *comm,
 	comm->action = FR_ACTION_DELETING_FILES;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
+	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->delete (comm, file_list);
 }
 
@@ -440,6 +441,7 @@ fr_command_extract (FrCommand  *comm,
 	comm->action = FR_ACTION_EXTRACTING_FILES;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
+	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->extract (comm,
 							 file_list, 
 							 dest_dir,
@@ -459,6 +461,7 @@ fr_command_test (FrCommand   *comm,
 	comm->action = FR_ACTION_TESTING_ARCHIVE;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
+	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->test (comm, password);
 }
 
@@ -475,7 +478,7 @@ void
 fr_command_recompress (FrCommand     *comm,
 		       FRCompression  compression)
 {
-	fr_command_progress (comm, -1.0);
+	fr_command_progress (comm, -1.0);	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->recompress (comm, compression);
 }
 
@@ -495,8 +498,8 @@ fr_command_escape (FrCommand     *comm,
  *                        accomplished. 
  */
 void
-fr_command_progress (FrCommand     *comm,
-		     double         fraction)
+fr_command_progress (FrCommand *comm,
+		     double     fraction)
 {
 	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[PROGRESS], 
@@ -506,8 +509,8 @@ fr_command_progress (FrCommand     *comm,
 
 
 void
-fr_command_message (FrCommand     *comm,
-		    const char    *msg)
+fr_command_message (FrCommand  *comm,
+		    const char *msg)
 {
 	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[MESSAGE], 
@@ -517,14 +520,22 @@ fr_command_message (FrCommand     *comm,
 
 
 void
-fr_command_set_n_files (FrCommand     *comm,
-			int            n_files)
+fr_command_set_n_files (FrCommand *comm,
+			int        n_files)
 {
 	comm->n_files = n_files;
 	comm->n_file = 0;
 }
 
 
+void
+fr_command_add_file (FrCommand *comm,
+		     FileData  *fdata)
+{
+	g_ptr_array_add (comm->files, fdata);
+}
+
+
 void
 fr_command_handle_error (FrCommand *comm,
 			 FRProcError *error)
